import { LitElement } from 'lit';
import { ComposedEvent } from '@patternfly/pfe-core';
import './pfe-search-droplist';
export declare type AutocompleteRequestFunction = (params: {
    query: string;
}, callback: (response: string[]) => void) => void;
export declare class AutocompleteClearEvent extends ComposedEvent {
    constructor();
}
export declare class AutocompleteShowEvent extends ComposedEvent {
    constructor();
}
/** Fired when the user submits the autocomplete input */
export declare class AutocompleteSearchEvent extends ComposedEvent {
    /** The search query */
    value: string;
    constructor(
    /** The search query */
    value: string);
}
/** Fired when the user selects an option from the dropdown */
export declare class AutocompleteSelectEvent extends ComposedEvent {
    /** The selected value */
    value: string;
    constructor(
    /** The selected value */
    value: string);
}
/**
 * Autocomplete provides options in a dropdown list as user types in an input box by
 * showing result from an API call or a static list.
 *
 * @summary Provides options in a dropdown list as user types in an input box
 *
 * @slot - Users must slot a single `<input>` element in to `<pfe-autocomplete>`
 *
 * @fires {AutocompleteShowEvent} show - When the search dropdown is shown
 * @fires {Event} pfe-autocomplete:options-shown - When the search dropdown is shown {@deprecated Use `show`}
 *
 * @fires {AutocompleteClearEvent} clear - Fires when a user clears the input field using the clear button.
 * @fires {CustomEvent<{ searchValue: '' }>} pfe-autocomplete:option-cleared -
 *                                           When the search dropdown is cleared
 *                                           ```js
 *                                           detail: {
 *                                             searchValue: ''
 *                                           }
 *                                           ```
 *                                           {@deprecated Use `clear`}
 *
 * @fires {AutocompleteSearchEvent} search
 *        Fires when a user performs search. By listening to this event you can get
 *        selected phrase by getting `event.value`.
 *
 * @fires {CustomEvent<{ searchValue: string }>} pfe-autocomplete:search-event
 *        Fires when a user performs search. By listening to this event you can get
 *        selected phrase by getting `e.detail.searchValue`.
 *        {@deprecated Use `search`}
 *
 * @fires {AutocompleteSelectEvent} select - Fires when a user selects an option from the dropdown list.
 * @fires {CustomEvent<{ optionValue: '' }>} pfe-autocomplete:option-selected
 *        Fires when a user selects an option from the dropdown list.
 *        ```js
 *        detail: {
 *          optionValue: String
 *        }
 *        ```
 *        {@deprecated Use `select`}
 *
 * @csspart {HTMLElement} container - The input wrapper
 * @csspart {SVGElement} icon - The loading icon
 * @csspart {HTMLButtonElement} clear-button - The clear button
 * @csspart {HTMLButtonElement} search-button - The search button
 * @csspart {PfeSearchDroplist} droplist - The search droplist
 * @csspart {PfeButton} text-search-button - The textual search button
 *                      Shown when [button-text] attr provided
 */
export declare class PfeAutocomplete extends LitElement {
    static readonly version = "{{version}}";
    static readonly styles: import("lit").CSSResult[];
    static readonly shadowRootOptions: {
        delegatesFocus: boolean;
        mode: ShadowRootMode;
        slotAssignment?: SlotAssignmentMode | undefined;
        customElements?: CustomElementRegistry | undefined;
    };
    /**
     * Set this attribute when you want to set a value in input box when web component is added to page.
     */
    initValue: string;
    /**
     * If you add this attribute on element, a loading icon is added in input box.
     * Add this attribute before the autocomplete API call and remove it
     * when the response is ready.
     */
    loading: boolean;
    /**
     * Add this attribute to disable the element.
     * By adding this attribute input box and buttons become disabled.
     */
    disabled: boolean;
    /** @deprecated use `disabled` */
    isDisabled?: boolean;
    /**
     * Users may type very fast. We allow to input box value changes trigger the
     * autocomplete API call only once per debounce period.
     * This attribute is optional. By default, it is set t0 300ms.
     */
    debounce: number;
    /** By observing `selected-value` attribute you can detect autocomplete selected value. */
    selectedValue?: string;
    /**
     * Set when you want to have a textual search button to the right of the input field.
     * The text in the button will contain the value you pass to the attribute.
     * If an empty string (`button-text=""`) or no string (`button-text`) is provided,
     * the text will default to "Search".
     */
    buttonText?: string;
    /** The list of search dropdown items */
    data: string[];
    /**
     * Optional translated string you provide for the [ARIA Live Region](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Live_Regions)
     * which will politely announce that the number of options the user can
     * select from as the autocomplete displays options.
     *
     * The default template is `"There are ${numOptions} suggestions. Use the up and down arrows to browse."`
     * `${numOptions}` will be dynamically replaced with the number of options that are shown.
     */
    announceTemplate: string;
    /**
     * @deprecated {use 'announce-template'}
     */
    get ariaAnnounceTemplate(): string;
    set ariaAnnounceTemplate(v: string);
    private activeIndex;
    private showTextualSearch;
    private _slot?;
    private _dropdown?;
    private _input?;
    constructor();
    connectedCallback(): void;
    render(): import("lit-html").TemplateResult<1>;
    disconnectedCallback(): void;
    private _inputInit;
    protected _initValueChanged(_oldVal: string | undefined, newVal: string): void;
    protected _isDisabledChanged(): void;
    protected _disabledChanged(): void;
    protected _buttonTextChanged(oldVal: string, newVal: string): void;
    private _inputChanged;
    private _clear;
    private _search;
    private _closeDroplist;
    private _openDroplist;
    private _optionSelected;
    private _doSearch;
    private _sendAutocompleteRequest;
    private _autocompleteCallback;
    private _reset;
    /**
     * Returns the text content of the active element
     * @param  activeIndex Index of an element in the droplist
     * @return  The text content inside of the given index as a string
     */
    private _activeOption;
    /**
     * Handle keyboard input, we care about arrow keys, enter, and escape
     */
    private _inputKeyUp;
    /**
     * Optional callback to asynchronously return search items
     * @param params User input
     * @param callback Call with resolved search items to populate the list
     */
    autocompleteRequest?: AutocompleteRequestFunction;
    /** Clear the search dropdown */
    clear(): Promise<void>;
    /** Perform the search */
    search(): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'pfe-autocomplete': PfeAutocomplete;
    }
}
